import { Field, ObjectType } from '@nestjs/graphql'
import { Column, CreateDateColumn, Entity, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm'
import { IsEmail } from 'class-validator'

import { UUID } from '../../graphql/uuidScalar'

import { UserRole } from './userRole'

@ObjectType()
@Entity()
export class User {
  @Field(() => UUID)
  @PrimaryGeneratedColumn('uuid')
  id: string

  @Field()
  @Column({ type: 'varchar', length: 255, unique: true })
  @IsEmail()
  email: string

  @Column({ type: 'varchar', length: 255 })
  passwordHash: string

  @Field(() => UserRole)
  @Column({ type: 'enum', enum: UserRole, default: UserRole.MODERATOR })
  role: UserRole

  @Field()
  @CreateDateColumn()
  createdAt: Date

  @Field()
  @UpdateDateColumn()
  updatedAt: Date
}
